<?php

declare(strict_types=1);

namespace Rowlinson\Api;

use Rowlinson\Api\Collections\PaginatedCollection;
use Rowlinson\Api\Responses\Organisation\OrganisationResponse;

class OrganisationClient extends AbstractClient
{
    /**
     * List all of the organisations
     *
     * @return PaginatedCollection<OrganisationResponse>
     */
    public function getOrganisations(int $page = 1): PaginatedCollection
    {
        $response = $this->get('organisations?' . http_build_query([
            'page' => $page,
        ]));

        $organisations = $this->serializer->deserialize(
            (string)$response->getBody(),
            'array<' . OrganisationResponse::class . '>', // @phpstan-ignore-line
            'json'
        );

        return new PaginatedCollection(
            $organisations,
            $page,
            $response->getPaginationPerPage(),
            $response->getPaginationTotalItems()
        );
    }
}
